@@ -2,8 +2,13 @@ context("DGEobj.utils - tests for runPower.R functions")
 skip_on_cran()
 skip_if_not_installed("statmod")
 skip_if_not_installed("RNASeqPower")
+skip_if_not_installed("ggplot2")
 
 test_that("runPower.R: runPower()", {
+    require(ggplot2)
+    require(statmod)
+    require(RNASeqPower)
+
     # data setup
     designMatrix <- model.matrix(~ 0 + ReplicateGroup, getItem(t_obj1, "design"))
 
